# Mirai Python Async SDK

[![License](https://img.shields.io/github/license/water-lift/aiomirai.svg)](LICENSE)
[![PyPI](https://img.shields.io/pypi/v/aiomirai.svg)](https://pypi.python.org/pypi/aiomirai)

Mirai Python Async SDK is a Python SDK with async I/O for [Mirai](https://github.com/mamoe/mirai)'s [Mirai API HTTP](https://github.com/mamoe/mirai-api-http) plugin.

Inspired by [CQHTTP Python Async SDK](https://github.com/cqmoe/python-aiocqhttp) and [Mirai Framework for Python](https://github.com/NatriumLab/python-mirai).

## Installation

```bash
pip install aiomirai
```

## Documentation

Coming s∞n...

## TODO

- [ ] Event parsing
- [ ] Documentation
- [ ] More TODOs...
